@@ -26,6 +26,8 @@
  */
 
 /* revision history:
+ * gimp    2.1.0a;  2004/11/29  hof: #159593
+ * gimp    2.1.0a;  2004/06/26  hof: #144649 use NULL for the default cursor as active_cursor
  * gimp    1.3.23b; 2003/12/06  hof: added mode GAP_BLUBOX_THRES_ALL
  * gimp    1.3.23a; 2003/11/26  hof: follow API changes for gimp_dialog_new
  * gimp    1.3.20d; 2003/10/14  hof: creation
@@ -197,14 +199,14 @@ gap_bluebox_bbp_new(gint32 layer_id)
 int
 gap_bluebox_dialog(GapBlueboxGlobalParams *bbp)
 {
-  if(gap_debug) fprintf(stderr, "\nSTART gap_bluebox_dialog\n");
+  if(gap_debug) printf("\nSTART gap_bluebox_dialog\n");
 
   gimp_ui_init ("gap_bluebox", FALSE);
   gap_stock_init();
 
   bbp->run_flag = FALSE;
   bbp->cursor_wait = gdk_cursor_new (GDK_WATCH);
-  bbp->cursor_acitve = gdk_cursor_new (GDK_TOP_LEFT_ARROW);
+  bbp->cursor_acitve = NULL; /* use the default cursor */
 
   gap_bluebox_create_dialog(bbp);
   gtk_widget_show (bbp->shell);
@@ -240,13 +242,14 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
   GtkWidget *label;
   GtkWidget *button;
   GtkWidget *check_button;
+  GtkWidget *hseparator;
   gint       row;
   GtkObject *adj;
 
 
   dlg = gimp_dialog_new (_("Bluebox"), GAP_BLUEBOX_PLUGIN_NAME,
                          NULL, 0,
-			 gimp_standard_help_func, GAP_BLUEBOX_PLUGIN_NAME".html",
+			 gimp_standard_help_func, GAP_BLUEBOX_HELP_ID,
 
 			 GIMP_STOCK_RESET, GAP_BLUEBOX_RESPONSE_RESET,
 			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -266,7 +269,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
 
   /*  the frame  */
 
-  frame = gtk_frame_new (_("Select By Color"));
+  frame = gimp_frame_new (_("Select By Color"));
   gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -282,7 +285,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
 
   /* the keycolor label */
   label = gtk_label_new (_("Keycolor:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
   gtk_table_attach_defaults (GTK_TABLE(table), label, 0, 1, row, row+1);
   gtk_widget_show (label);
 
@@ -292,7 +295,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
 				  &bbp->vals.keycolor,
 				  GIMP_COLOR_AREA_FLAT);
   gtk_table_attach (GTK_TABLE (table), button, 1, 3, row, row+1,
-		    GTK_FILL, GTK_SHRINK, 0, 0) ;
+		    GTK_FILL | GTK_EXPAND, GTK_SHRINK, 0, 0) ;
   gtk_widget_show (button);
   g_object_set_data(G_OBJECT(button), "bbp", bbp);
   bbp->keycolor_button = button;
@@ -319,7 +322,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
 			      TRUE,           /* constrain */
 			      0.0, 1.0,       /* lower/upper unconstrained */
 			      _("Sharp pixel selection by color with 0.0. Greater values than 0 "
-			        "makes selection with more or less varaible alpha value depending "
+			        "makes selection with more or less variable alpha value depending "
 				"on difference to the keycolor"), NULL);
   bbp->tolerance_adj = adj;
   g_object_set_data(G_OBJECT(adj), "bbp", bbp);
@@ -367,8 +370,9 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
   row++;
 
   label = gtk_label_new(_("Feather Edges:"));
-  gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-  gtk_table_attach(GTK_TABLE (table), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
+  gtk_table_attach(GTK_TABLE (table), label, 0, 1, row, row + 1
+                  , GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show(label);
 
   /* check button */
@@ -420,7 +424,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
   row++;
 
   label = gtk_label_new(_("Automatic Preview:"));
-  gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
   gtk_table_attach(GTK_TABLE (table), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show(label);
 
@@ -442,7 +446,7 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
   button = gtk_button_new_with_label(_("Preview"));
   gtk_table_attach(GTK_TABLE (table), button, 2, 3, row, row + 1, GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show(button);
-  gimp_help_set_help_data(button, _("Show preview as seperate image"), NULL);
+  gimp_help_set_help_data(button, _("Show preview as separate image"), NULL);
   g_signal_connect (button, "clicked",
                     G_CALLBACK (p_apply_callback),
                     bbp);
@@ -463,6 +467,11 @@ gap_bluebox_create_dialog (GapBlueboxGlobalParams *bbp)
                     G_CALLBACK (p_gdouble_adjustment_callback),
                     &bbp->pv_size_percent);
 
+
+  hseparator = gtk_hseparator_new ();
+  gtk_widget_show (hseparator);
+  gtk_box_pack_start (GTK_BOX (main_vbox), hseparator, FALSE, FALSE, 0);
+
   /*  Show the main containers  */
 
   gtk_widget_show (main_vbox);
@@ -848,7 +857,7 @@ p_radio_create_thres_mode(GtkWidget *table, int row, int col, GapBlueboxGlobalPa
   gboolean  l_radio_pressed;
 
   label = gtk_label_new(_("Threshold Mode:"));
-  gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
+  gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.0);
   gtk_table_attach( GTK_TABLE (table), label, col, col+1, row, row+1, GTK_FILL, GTK_FILL, 0, 10);
   gtk_widget_show(label);
 
