@@ -25,6 +25,7 @@
  *     - xanim              2.80 exporting edition with extensions from loki entertainment.
  *                          set environment GAP_XANIM_PROG to configure where to find xanim
  *                          (default: search xanim in your PATH)
+ *     - cd                 (UNIX command)
  *     - grep               (UNIX command)
  *     - rm                 (UNIX command is used to delete by wildcard (expanded by /bin/sh)
  *                                and to delete a directory with all files
@@ -48,6 +49,7 @@
  */
 
 /* revision history
+ * gimp    2.1.0;   2004/12/06  hof: use g_file_test(dir, G_FILE_TEST_IS_DIR) to check for directory
  * gimp    1.3.26c; 2004/03/09  hof: bugfix (gimp_destroy_params)
  * gimp    1.3.20a; 2003/09/15  hof: should fix compile problems on WIN32 (#122220)
  *                                   (but will not run at WIN OS)
@@ -88,23 +90,22 @@
 #  endif
 #endif
 
-#ifdef G_OS_WIN32
-#include <direct.h>		/* For _mkdir() */
-#define mkdir(path,mode) _mkdir(path)
-#endif
+
+#define GAP_XANIM_HELP_ID  "plug-in-gap-xanim-decode"
 
 /* GAP includes */
 #include "gap_lib.h"
 #include "gap_arr_dialog.h"
 #include "gap_decode_xanim.h"
+#include "gap_file_util.h"
 
 extern      int gap_debug; /* ==0  ... dont print debug infos */
 
 static char *global_xanim_input_dir = NULL;
 static char *global_xanim_working_dir = NULL;
 
-gchar global_xanim_prog[500];
-gchar *global_errlist = NULL;
+static gchar global_xanim_prog[500];
+static gchar *global_errlist = NULL;
 
 gint32  global_delete_number;
 /* fileformats supported by gap_decode_xanim */
@@ -116,11 +117,6 @@ typedef enum
  , XAENC_JPEG
 } GapXAnimFormats;
 
-#ifdef G_OS_WIN32
-#define MKDIR_MODE 0  /* not relevant for WIN mkdir */
-#else
-#define MKDIR_MODE (S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH )
-#endif
 
 /* ============================================================================
  * p_xanim_info
@@ -184,7 +180,7 @@ p_xanim_info(char *errlist)
 
   l_idx++;
   gap_arr_arg_init(&argv[l_idx], GAP_ARR_WGT_LABEL_LEFT);
-  argv[l_idx].label_txt = _("An error occured while trying to call xanim:");  
+  argv[l_idx].label_txt = _("An error occurred while trying to call xanim:");  
 
   l_idx++;
   gap_arr_arg_init(&argv[l_idx], GAP_ARR_WGT_LABEL_LEFT);
@@ -195,6 +191,7 @@ p_xanim_info(char *errlist)
   gap_arr_arg_init(&argv[l_idx], GAP_ARR_WGT_LABEL_LEFT);
   argv[l_idx].label_txt = errlist;
 
+
   l_idx++;
 
   /* the  Action Button */
@@ -231,7 +228,7 @@ p_xanim_dialog   (gint32 *first_frame,
 		  gint32  *autoload,
 		  gint32  *run_xanim_asynchron)
 {
-#define XADIALOG_NUM_ARGS 12
+#define XADIALOG_NUM_ARGS 13
   static GapArrArg  argv[XADIALOG_NUM_ARGS];
   static char *radio_args[3]  = { "XCF", "PPM", "JPEG" };
 
@@ -316,10 +313,15 @@ p_xanim_dialog   (gint32 *first_frame,
   argv[10].int_ret   = 1;
 
   gap_arr_arg_init(&argv[11], GAP_ARR_WGT_LABEL_LEFT);
-  argv[11].label_txt = _("\nWarning: xanim 2.80 has only limited MPEG support.\n"
+  argv[11].label_txt = _("\nWarning: xanim 2.80 is old unmaintained software\n"
+                         "and has only limited MPEG support.\n"
 			 "Most of the frames (type P and B) will be skipped.");
+
+  gap_arr_arg_init(&argv[12], GAP_ARR_WGT_HELP_BUTTON);
+  argv[12].help_id = GAP_XANIM_HELP_ID;
+
    
-  if(TRUE == gap_arr_ok_cancel_dialog(_("Split any Xanim readable Video to Frames"), 
+  if(TRUE == gap_arr_ok_cancel_dialog(_("Xanim based extraction (DEPRECATED)"), 
 			    _("Select Frame Range"), XADIALOG_NUM_ARGS, argv))
   {
      if(argv[1].int_ret < argv[2].int_ret )
@@ -397,27 +399,8 @@ p_build_gap_framename(char *framename, gint32 sizeof_framename, gint32 frame_nr,
    g_snprintf(framename, sizeof_framename, "%s%06d.%s", basename, (int)frame_nr, ext);
 }
 
-int
-p_is_directory(char *fname)
-{
-  struct stat  l_stat_buf;
 
-  /* get File status */
-  if (0 != stat(fname, &l_stat_buf))
-  {
-    /* stat error (file does not exist) */
-    return(0);
-  }
-  
-  if(S_ISDIR(l_stat_buf.st_mode))
-  {
-    return(1);
-  }
-    
-  return(0);
-}	/* end p_is_directory  */
-
-void
+static void
 p_dirname(char *fname)
 {
   int l_idx;
@@ -889,7 +872,7 @@ p_start_xanim_process(gint32 first_frame, gint32 last_frame,
 
      /* asynchron start */
      remove(l_xanim_pidfile);   
-     /* generate a shelscript */
+     /* generate a shellscript */
      l_fp = fopen(l_xanim_startscript, "w+");
      if (l_fp != NULL)
      {
@@ -910,7 +893,7 @@ p_start_xanim_process(gint32 first_frame, gint32 last_frame,
 	 /* fprintf(l_fp, "exit $XANIM_PID\n"); */
 	 fclose(l_fp);
 
-	 chmod(l_xanim_startscript, MKDIR_MODE);
+	 gap_file_chmod(l_xanim_startscript, GAP_FILE_MKDIR_MODE);
      }
 
      l_rc = system(l_xanim_startscript);
@@ -1115,7 +1098,7 @@ gap_xanim_decode(GimpRunMode run_mode)
     if (extract_video)
     {
          /* for the frames we need a directory named "input" */
-         if (p_is_directory(global_xanim_input_dir))
+         if (g_file_test(global_xanim_input_dir, G_FILE_TEST_IS_DIR))
          {
            /* the input directory already exists,
             * remove frames
@@ -1126,9 +1109,9 @@ gap_xanim_decode(GimpRunMode run_mode)
          else
          {
             /* create input directory (needed by xanim to store the frames) */
-            mkdir(global_xanim_input_dir, MKDIR_MODE);
+            gap_file_mkdir(global_xanim_input_dir, GAP_FILE_MKDIR_MODE);
 
-            if (p_is_directory(global_xanim_input_dir))
+            if (g_file_test(global_xanim_input_dir, G_FILE_TEST_IS_DIR))
             {
               l_input_dir_created_by_myself = TRUE;
             }
@@ -1203,9 +1186,9 @@ gap_xanim_decode(GimpRunMode run_mode)
        p_dirname(l_dst_dir);
        if (*l_dst_dir != '\0')
        {
-	 if ( !p_is_directory(l_dst_dir) )
+	 if ( !g_file_test(l_dst_dir, G_FILE_TEST_IS_DIR) )
 	 {
-            mkdir (l_dst_dir, MKDIR_MODE);
+            gap_file_mkdir (l_dst_dir, GAP_FILE_MKDIR_MODE);
 	 }
        }
 
