@@ -512,7 +512,7 @@ GimpPlugInInfo PLUG_IN_INFO =
     {GIMP_PDB_IMAGE, "image", "Input image (current one of the video frames)"},
     {GIMP_PDB_DRAWABLE, "drawable", "Input drawable (unused)"},
     {GIMP_PDB_INT32, "nr", "start frame number for the first frame (usual value is 1)"},
-    {GIMP_PDB_INT32, "digits", "how many digits to use for the framenumber part (1 upto 6)"},
+    {GIMP_PDB_INT32, "digits", "how many digits to use for the framenumber part (1 upto 8)"},
   };
   static int nargs_renumber = G_N_ELEMENTS (args_renumber);
 
@@ -555,6 +555,8 @@ GimpPlugInInfo PLUG_IN_INFO =
 				    ", 29:add bw copy as layermask"
 				    ", 30:delete layermask"
 				    ", 31:apply layermask"
+				    ", 32:copy layermask from layer above"
+				    ", 33:copy layermask from layer below"
 				    },
     {GIMP_PDB_INT32, "select_mode", "Mode how to identify a layer: 0-3 by layername 0=equal, 1=prefix, 2=suffix, 3=contains, 4=layerstack_numberslist, 5=inv_layerstack, 6=all_visible"},
     {GIMP_PDB_INT32, "select_case", "0: ignore case 1: select_string is case sensitive"},
@@ -1858,7 +1860,7 @@ run (const gchar *name
   {
       gint32 digits;
 
-      digits = 6;
+      digits = GAP_LIB_DEFAULT_DIGITS;
       if (run_mode == GIMP_RUN_NONINTERACTIVE)
       {
         if (n_params != nargs_renumber)
@@ -1964,13 +1966,16 @@ run (const gchar *name
 
  if(l_rc_image < 0)
  {
+    if(gap_debug) printf("gap_main: return GIMP_PDB_EXECUTION_ERROR\n");
     status = GIMP_PDB_EXECUTION_ERROR;
  }
  else
  {
+    if(gap_debug) printf("gap_main: return OK\n");
     /* most gap_plug-ins return an image_id in values[1] */
     if (values[1].type == GIMP_PDB_IMAGE)
     {
+      if(gap_debug) printf("gap_main: return image_id:%d\n", (int)l_rc_image);
       values[1].data.d_int32 = l_rc_image;  /* return image id  of the resulting (current frame) image */
     }
  }
