@@ -54,6 +54,12 @@
 /* common used spinbutton char width */
 #define SB_WIDTH 10
 
+#define GAP_HELP_ID_CROP    "plug-in-gap-anim-crop"
+#define GAP_HELP_ID_RESIZE  "plug-in-gap-anim-resize"
+#define GAP_HELP_ID_SCALE   "plug-in-gap-anim-scale"
+
+
+
 typedef struct
 {
   GapRangeOpsAsiz asiz_mode;    /* GAP specific resize mode GAP_ASIZ_SCALE, GAP_ASIZ_RESIZE, GAP_ASIZ_CROP */
@@ -153,7 +159,7 @@ p_resize_bound_off_y (GapResizePrivateType *res_private,
  */
 static void
 p_res_cancel_callback (GtkWidget *widget,
-                                gpointer   data)
+                       GapResizePrivateType *res_private)
 {
   gtk_main_quit ();
 }  /* end p_res_cancel_callback */
@@ -164,11 +170,8 @@ p_res_cancel_callback (GtkWidget *widget,
  */
 static void
 p_res_ok_callback (GtkWidget *widget,
-                    gpointer   data)
+                   GapResizePrivateType *res_private)
 {
-  GapResizePrivateType *res_private;
-  
-  res_private = (GapResizePrivateType *)data;
   if(res_private)
   {
     res_private->run = TRUE;
@@ -176,6 +179,31 @@ p_res_ok_callback (GtkWidget *widget,
   }
 }  /* end p_res_ok_callback */
 
+/* -----------------------------
+ * p_res_help_callback
+ * -----------------------------
+ */
+static void
+p_res_help_callback (GtkWidget *widget,
+                     GapResizePrivateType *res_private)
+{
+  if(res_private)
+  {
+    switch(res_private->asiz_mode)
+    {
+      case GAP_ASIZ_SCALE:
+        gimp_standard_help_func(GAP_HELP_ID_SCALE, res_private->dlg);
+        break;
+      case GAP_ASIZ_RESIZE:
+        gimp_standard_help_func(GAP_HELP_ID_RESIZE, res_private->dlg);
+        break;
+      case GAP_ASIZ_CROP:
+        gimp_standard_help_func(GAP_HELP_ID_CROP, res_private->dlg);
+        break;
+    }
+  }
+}  /* end p_res_help_callback */
+
 /* -----------------------------
  * p_set_size_spinbuttons
  * -----------------------------
@@ -591,13 +619,13 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
   switch(res_private->asiz_mode)
   {
     case GAP_ASIZ_SCALE:
-      frame        = gtk_frame_new (_("Scale Frames"));
+      frame        = gimp_frame_new (_("Scale Frames"));
       break;
     case GAP_ASIZ_RESIZE:
-      frame        = gtk_frame_new (_("Resize Frames"));
+      frame        = gimp_frame_new (_("Resize Frames"));
       break;
     case GAP_ASIZ_CROP:
-      frame        = gtk_frame_new (_("Crop Frames"));
+      frame        = gimp_frame_new (_("Crop Frames"));
       break;
   }
 
@@ -605,7 +633,7 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
   main_vbox = gtk_vbox_new (FALSE, 4);
   gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 4);
   /* gtk_container_add (GTK_CONTAINER (GTK_DIALOG (res_private->shell)->vbox), main_vbox);
-   */                
+   */
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (res_private->shell)->vbox), main_vbox, TRUE, TRUE, 0);
 
   /* button hbox */
@@ -613,7 +641,7 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
   gtk_box_set_homogeneous (GTK_BOX (GTK_DIALOG (res_private->shell)->action_area), FALSE);
 
   hbbox = gtk_hbutton_box_new ();
-  gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbbox), 4);
+  gtk_box_set_spacing (GTK_BOX (hbbox), 4);
   gtk_box_pack_end (GTK_BOX (GTK_DIALOG (res_private->shell)->action_area), hbbox, FALSE, FALSE, 0);
   gtk_widget_show (hbbox);
 
@@ -637,14 +665,14 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
 
 
   /*  the original width & height labels  */
-  label = gtk_label_new (_("Original Width:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("Current width:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
 
-  label = gtk_label_new (_("Height:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("Current height:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
@@ -665,14 +693,14 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
 
 
   /*  the new size labels  */
-  label = gtk_label_new (_("New Width:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("New width:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
 
-  label = gtk_label_new (_("Height:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("New height:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
@@ -719,14 +747,14 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
 
 
   /*  the scale ratio labels  */
-  label = gtk_label_new (_("Ratio X:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("X ratio:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
 
-  label = gtk_label_new (_("Y:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  label = gtk_label_new (_("Y ratio:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
   gtk_widget_show (label);
@@ -797,7 +825,7 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
   if(res_private->asiz_mode != GAP_ASIZ_SCALE)
   {
     /*  the offset frame  */
-    frame = gtk_frame_new (_("Offset"));
+    frame = gimp_frame_new (_("Offset"));
     gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
     gtk_widget_show (frame);
 
@@ -817,13 +845,13 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
     
     /* the x/y offest labels */
     label = gtk_label_new (_("X:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
     gtk_table_attach (GTK_TABLE (table3), label, 0, 1, 0, 1,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
     gtk_widget_show (label);
     
     label = gtk_label_new (_("Y:"));
-    gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
     gtk_table_attach (GTK_TABLE (table3), label, 0, 1, 1, 2,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
     gtk_widget_show (label);
@@ -892,8 +920,7 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
     abox = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
     gtk_box_pack_start (GTK_BOX (vbox), abox, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new (NULL);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
+    frame = gimp_frame_new (NULL);
     gtk_container_add (GTK_CONTAINER (abox), frame);
 
     /* the GimpOffsetArea widget */
@@ -914,6 +941,13 @@ gap_resi_dialog (gint32 image_id, GapRangeOpsAsiz asiz_mode, char *title_text,
 
   /*  Action area  */
 
+  button = gtk_button_new_from_stock ( GTK_STOCK_HELP);
+  gtk_box_pack_end (GTK_BOX (hbbox), button, TRUE, TRUE, 0);
+  gtk_widget_show (button);
+  g_signal_connect (GTK_OBJECT (button), "clicked",
+                    G_CALLBACK  (p_res_help_callback),
+                    res_private);
+
   button = gtk_button_new_from_stock ( GIMP_STOCK_RESET);
   gtk_box_pack_start (GTK_BOX (hbbox), button, TRUE, TRUE, 0);
   gtk_widget_show (button);
